@@ -22,6 +22,7 @@ describe 'placement' do
       )}
 
       it { should contain_placement_config('placement/randomize_allocation_candidates').with_value('<SERVICE DEFAULT>') }
+      it { should contain_placement_config('placement/allocation_conflict_retry_count').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'with overridden parameters' do
@@ -29,7 +30,9 @@ describe 'placement' do
         {
           :ensure_package                  => 'absent',
           :sync_db                         => false,
+          :state_path                      => '/var/lib/placement',
           :randomize_allocation_candidates => true,
+          :allocation_conflict_retry_count => 10,
         }
       end
 
@@ -51,7 +54,9 @@ describe 'placement' do
         :tag     => ['openstack', 'placement-package'],
       )}
 
+      it { should contain_placement_config('DEFAULT/state_path').with_value('/var/lib/placement') }
       it { should contain_placement_config('placement/randomize_allocation_candidates').with_value(true) }
+      it { should contain_placement_config('placement/allocation_conflict_retry_count').with_value(10) }
     end
   end
 
@@ -71,10 +76,24 @@ describe 'placement' do
             :common_package_name => 'placement-common',
           }
         when 'RedHat'
-          {
-            :python_package_name => 'python2-placement',
-            :common_package_name => 'openstack-placement-common',
-          }
+          if facts[:operatingsystem] == 'Fedora'
+            {
+              :python_package_name => 'python3-placement',
+              :common_package_name => 'openstack-placement-common',
+            }
+          else
+            if facts[:operatingsystemmajrelease] > '7'
+              {
+                :python_package_name => 'python3-placement',
+                :common_package_name => 'openstack-placement-common',
+              }
+            else
+              {
+                :python_package_name => 'python2-placement',
+                :common_package_name => 'openstack-placement-common',
+              }
+            end
+          end
         end
       end
 
