@@ -41,6 +41,7 @@ describe 'placement::keystone::authtoken' do
         is_expected.to contain_placement_config('keystone_authtoken/token_cache_time').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_placement_config('keystone_authtoken/service_token_roles').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_placement_config('keystone_authtoken/service_token_roles_required').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_placement_config('keystone_authtoken/interface').with_value('<SERVICE DEFAULT>')
       }
     end
 
@@ -81,6 +82,7 @@ describe 'placement::keystone::authtoken' do
           :token_cache_time               => '301',
           :service_token_roles            => ['service'],
           :service_token_roles_required   => false,
+          :interface                      => 'internal',
         })
       end
 
@@ -118,6 +120,7 @@ describe 'placement::keystone::authtoken' do
         is_expected.to contain_placement_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
         is_expected.to contain_placement_config('keystone_authtoken/service_token_roles').with_value(params[:service_token_roles])
         is_expected.to contain_placement_config('keystone_authtoken/service_token_roles_required').with_value(params[:service_token_roles_required])
+        is_expected.to contain_placement_config('keystone_authtoken/interface').with_value(params[:interface])
       }
 
       it { is_expected.to contain_package('python-memcache') }
